@@ -13,24 +13,24 @@
 #' for rescaled time, 0<=bernstein1_l<bernstein1_r<=1
 #' @param bernstein2_l,bernstein2_r left and right truncation of Bernstein polynomial basis functions
 #' for rescaled frequency, 0<=bernstein2_l<bernstein2_r<=1
-#' @param L truncation parameter of DP in stick breaking representation
+#' @param L number of terms in fast DP approximation
 #' @return A list of prior parameter values
 #' @export
 #'
 bdp_dw_prior_params_gen <- function(M = 1,
-                             g0.alpha = 1,
-                             g0.beta = 1,
-                             k1.theta = 0.01,
-                             k2.theta = 0.01,
-                             tau.alpha = 0.001,
-                             tau.beta = 0.001,
-                             k1max = 100,
-                             k2max = 100,
-                             L = 20,
-                             bernstein1_l = 0.1,
-                             bernstein1_r = 0.9,
-                             bernstein2_l = 0.1,
-                             bernstein2_r = 0.9){
+                                    g0.alpha = 1,
+                                    g0.beta = 1,
+                                    k1.theta = 0.01,
+                                    k2.theta = 0.01,
+                                    tau.alpha = 0.001,
+                                    tau.beta = 0.001,
+                                    k1max = 100,
+                                    k2max = 100,
+                                    L = 10,
+                                    bernstein1_l = 0.1,
+                                    bernstein1_r = 0.9,
+                                    bernstein2_l = 0.1,
+                                    bernstein2_r = 0.9){
 
   # PRIOR PAREMETERS CHECK
   stopifnot(!is.null(M)); stopifnot(M > 0)
@@ -83,10 +83,10 @@ bdp_dw_prior_params_gen <- function(M = 1,
 #' @export
 #'
 bdp_dw_mcmc_params_gen <- function(Ntotal = 1.1e5,
-                            burnin = 6e4,
-                            thin = 10,
-                            adaptive.batchSize = 50,
-                            adaptive.targetAcceptanceRate = 0.44){
+                                   burnin = 6e4,
+                                   thin = 10,
+                                   adaptive.batchSize = 50,
+                                   adaptive.targetAcceptanceRate = 0.44){
 
 
   # MCMC parameters check
@@ -115,6 +115,7 @@ bdp_dw_mcmc_params_gen <- function(Ntotal = 1.1e5,
 }
 
 #' Calculating the estimated posterior mean, median and credible region (tv-PSD)
+#' @importFrom stats qgamma
 #'
 #' @param post_sample the posterior sample generated by \link{bdp_dw_mcmc}.
 #' @param rescaled_time,freq numeric vectors forming a rectangular grid on which the estimated tv-PSD is evaluated.
@@ -142,6 +143,9 @@ bdp_dw_est_post_stats <- function(post_sample, rescaled_time, freq, unif_CR = FA
   bernstein1_r <- (post_sample$prior_params)$bernstein1_r
   bernstein2_l <- (post_sample$prior_params)$bernstein2_l
   bernstein2_r <- (post_sample$prior_params)$bernstein2_r
+  
+  L <- (post_sample$prior_params)$L
+  M <- (post_sample$prior_params)$M
 
   db.list_1 <- dbList_dw_Bern(rescaled_time, k1max, bernstein1_l, bernstein1_r)
   db.list_2 <- dbList_dw_Bern(rescaled_freq, k2max, bernstein2_l, bernstein2_r)
@@ -149,16 +153,24 @@ bdp_dw_est_post_stats <- function(post_sample, rescaled_time, freq, unif_CR = FA
   post_funval <- array(NA, dim = c(length(rescaled_time), length(rescaled_freq), length(post_sample$k1)))
 
   for (j in 1:(dim(post_funval)[3])) {
+    
     k1 <- (post_sample$k1)[j]
     k2 <- (post_sample$k2)[j]
-    V <- (post_sample$V)[,j]
+    tau <- (post_sample$tau)[j]
+    E <- (post_sample$E)[,j]
     W1 <- (post_sample$W1)[,j]
     W2 <- (post_sample$W2)[,j]
     beta_basis_1_k <- db.list_1[[k1]]
     beta_basis_2_k <- db.list_2[[k2]]
-    tau <- (post_sample$tau)[j]
-
-    post_funval[ , , j] <- tau * t(qpsd_dw(V, W1, W2, k1, k2, beta_basis_1_k, beta_basis_2_k))
+    
+    p <- qgamma(1 - cumsum(E[-(L+1)])/sum(E), 
+                shape = M/L, rate = 1)
+    unip <- p/sum(p)
+    
+    selector1 <- findInterval(W1, (1:k1)/k1, left.open = T) + 1 
+    selector2 <- findInterval(W2, (1:k2)/k2, left.open = T) + 1 
+    
+    post_funval[ , , j] <- tau * t(crossprod(unip * beta_basis_2_k[selector2, ],  beta_basis_1_k[selector1, ]))
 
   }
   
@@ -561,7 +573,7 @@ sim_tvarma12 <- function(len_d,
 #' @param print_interval If monitor = TRUE, then this value indicates number of iterations after which a status is printed to console;
 #' If monitor = FALSE, it does not have any effect
 #' @param unif_CR a Boolean value (default FALSE) indicating whether to calculate the uniform credible region
-#' @param res_time,freq a set of grid lines in \eqn{[0,1]} and \eqn{[0,\pi]}, respectively, specifying where to evaluate the estimated tv-PSD
+#' @param rescaled_time,freq a set of grid lines in \eqn{[0,1]} and \eqn{[0,\pi]}, respectively, specifying where to evaluate the estimated tv-PSD
 #' @param Ntotal total number of iterations to run the Markov chain
 #' @param burnin number of initial iterations to be discarded
 #' @param thin thinning number (for post-processing of the posterior sample)
@@ -594,19 +606,20 @@ sim_tvarma12 <- function(len_d,
 #' \dontrun{
 #'
 #' ##
-#' ## Example: Applying BDP-DW method to a multi-peaked tvMA(1) process
+#' ## Example: Applying BDP-DW method to a multi-peaked heavy-tailed tvMA(1) process
 #' ##
 #'
 #' # set seed
-#' set.seed(200)
+#' set.seed(2)
 #' # set the length of time series
 #' len_d <- 1500
-#' # generate data from DGP LS2c defined in Section 4.2.2 of Tang et al. (2023). 
+#' # generate data from DGP LS2b defined in Section 4.2.2 of Tang et al. (2023). 
 #' # see also ?sim_tvarma12
-#' sim_data <- sim_tvarma12(len_d = 1500, dgp = "LS2", innov_distribution = "c")
+#' sim_data <- sim_tvarma12(len_d = 1500, dgp = "LS2", innov_distribution = "b")
+#' set.seed(NULL)
 #' # specify grid-points at which the tv-PSD is evaluated
 #' res_time <- seq(0, 1, by = 0.005); freq <- pi * seq(0, 1, by = 0.01)
-#' # calculate the true tv-PSD of DGP LS2c at the pre-specified grid
+#' # calculate the true tv-PSD of DGP LS2b at the pre-specified grid
 #' true_tvPSD <- psd_tvarma12(rescaled_time = res_time, freq = freq, dgp = "LS2")
 #' # plot the true tv-PSD
 #' # type ?plot.bdp_dw_tv_psd for more info
@@ -644,32 +657,32 @@ sim_tvarma12 <- function(len_d,
 #' <arXiv:2303.11561>
 #' @export
 gibbs_bdp_dw <- function(data,
-                     m,
-                     likelihood_thinning = 1,
-                     monitor = TRUE,
-                     print_interval = 100,
-                     unif_CR = FALSE,
-                     res_time,
-                     freq,
-                     Ntotal = 1.1e5,
-                     burnin = 6e4,
-                     thin = 10,
-                     adaptive.batchSize = 50,
-                     adaptive.targetAcceptanceRate = 0.44,
-                     M = 1,
-                     g0.alpha = 1,
-                     g0.beta = 1,
-                     k1.theta = 0.01,
-                     k2.theta = 0.01,
-                     tau.alpha = 0.001,
-                     tau.beta = 0.001,
-                     k1max = 100,
-                     k2max = 100,
-                     L = 20,
-                     bernstein1_l = 0.1,
-                     bernstein1_r = 0.9,
-                     bernstein2_l = 0.1,
-                     bernstein2_r = 0.9){
+                         m,
+                         likelihood_thinning = 1,
+                         monitor = TRUE,
+                         print_interval = 100,
+                         unif_CR = FALSE,
+                         rescaled_time,
+                         freq,
+                         Ntotal = 1.1e5,
+                         burnin = 6e4,
+                         thin = 10,
+                         adaptive.batchSize = 50,
+                         adaptive.targetAcceptanceRate = 0.44,
+                         M = 1,
+                         g0.alpha = 1,
+                         g0.beta = 1,
+                         k1.theta = 0.01,
+                         k2.theta = 0.01,
+                         tau.alpha = 0.001,
+                         tau.beta = 0.001,
+                         k1max = 100,
+                         k2max = 100,
+                         L = 10,
+                         bernstein1_l = 0.1,
+                         bernstein1_r = 0.9,
+                         bernstein2_l = 0.1,
+                         bernstein2_r = 0.9){
   
   
   mcmc_params <- bdp_dw_mcmc_params_gen(Ntotal,
@@ -704,19 +717,19 @@ gibbs_bdp_dw <- function(data,
   
   
   post_funval_stats <- bdp_dw_est_post_stats(post_sample = post_sample,
-                                         rescaled_time = res_time, 
-                                         freq = freq, unif_CR = unif_CR)
+                                             rescaled_time = rescaled_time, 
+                                             freq = freq, unif_CR = unif_CR)
   
   
   
   result <- list(call = cl, 
                  data = post_sample$data,
-                 rescaled_time = res_time,
+                 rescaled_time = rescaled_time,
                  frequency = freq,
                  k1 = post_sample$k1, 
                  k2 = post_sample$k2, 
                  tau = post_sample$tau,
-                 V = post_sample$V, 
+                 E = post_sample$E, 
                  W1 = post_sample$W1, 
                  W2 = post_sample$W2, 
                  lpost = post_sample$lpost,
